@@ -22,7 +22,8 @@
 
 #include "clientcapabilities.h"
 
-#include <QMutex>
+namespace Akonadi {
+namespace Server {
 
 /** Aggregates client capabilities of all active sessions. */
 namespace ClientCapabilityAggregator
@@ -39,4 +40,7 @@ namespace ClientCapabilityAggregator
   int maximumNotificationMessageVersion();
 }
 
+} // namespace Server
+} // namespace Akonadi
+
 #endif // CLIENTCAPABILITYAGGREGATOR_H
