@@ -23,6 +23,7 @@
 #include <handler.h>
 
 namespace Akonadi {
+namespace Server {
 
 /**
   @ingroup akonadi_server_handler
@@ -40,6 +41,7 @@ class Expunge : public Handler
     bool parseStream();
 };
 
-}
+} // namespace Server
+} // namespace Akonadi
 
 #endif
