@@ -24,6 +24,7 @@
 #include "scope.h"
 
 namespace Akonadi {
+namespace Server {
 
 /**
   @ingroup akonadi_server_handler
@@ -55,6 +56,7 @@ class  Remove : public Handler
     Scope mScope;
 };
 
-}
+} // namespace Server
+} // namespace Akonadi
 
 #endif
