@@ -32,6 +32,7 @@
 #include "storage/dbconfig.h"
 #include "storage/itemretriever.h"
 #include "storage/parttypehelper.h"
+#include "storage/partstreamer.h"
 
 #include "libs/imapparser_p.h"
 #include "libs/protocol_p.h"
@@ -68,7 +69,7 @@ Store::Store( Scope::SelectionScope scope )
 {
 }
 
-bool Store::replaceFlags( const PimItem::List &item, const QList<QByteArray> &flags )
+bool Store::replaceFlags( const PimItem::List &item, const QVector<QByteArray> &flags )
 {
   Flag::List flagList = HandlerHelper::resolveFlags( flags );
   DataStore *store = connection()->storageBackend();
@@ -80,19 +81,19 @@ bool Store::replaceFlags( const PimItem::List &item, const QList<QByteArray> &fl
   return true;
 }
 
-bool Store::addFlags( const PimItem::List &items, const QList<QByteArray> &flags, bool &flagsChanged )
+bool Store::addFlags( const PimItem::List &items, const QVector<QByteArray> &flags, bool &flagsChanged )
 {
   const Flag::List flagList = HandlerHelper::resolveFlags( flags );
   DataStore *store = connection()->storageBackend();
 
-  if ( !store->appendItemsFlags( items, flagList, flagsChanged ) ) {
+  if ( !store->appendItemsFlags( items, flagList, &flagsChanged ) ) {
     akDebug() << "Store::addFlags: Unable to add new item flags";
     return false;
   }
   return true;
 }
 
-bool Store::deleteFlags( const PimItem::List &items, const QList<QByteArray> &flags )
+bool Store::deleteFlags( const PimItem::List &items, const QVector<QByteArray> &flags )
 {
   DataStore *store = connection()->storageBackend();
 
@@ -126,7 +127,7 @@ bool Store::replaceTags( const PimItem::List &item, const ImapSet &tags )
 bool Store::addTags( const PimItem::List &items, const ImapSet &tags, bool &tagsChanged )
 {
   const Tag::List tagList = HandlerHelper::resolveTags( tags );
-  if ( !connection()->storageBackend()->appendItemsTags( items, tagList, tagsChanged ) ) {
+  if ( !connection()->storageBackend()->appendItemsTags( items, tagList, &tagsChanged ) ) {
     akDebug() << "Store::addTags: Unable to add new item tags";
     return false;
   }
@@ -153,7 +154,7 @@ bool Store::parseStream()
 
   // retrieve selected items
   SelectQueryBuilder<PimItem> qb;
-  ItemQueryHelper::scopeToQuery( mScope, connection(), qb );
+  ItemQueryHelper::scopeToQuery( mScope, connection()->context(), qb );
   if ( !qb.exec() ) {
     return failureResponse( "Unable to retrieve items" );
   }
@@ -213,7 +214,7 @@ bool Store::parseStream()
     // handle commands that can be applied to more than one item
     if ( command == AKONADI_PARAM_FLAGS ) {
       bool flagsChanged = true;
-      const QList<QByteArray> flags = m_streamParser->readParenthesizedList();
+      const QVector<QByteArray> flags = m_streamParser->readParenthesizedList().toVector();
       if ( op == Replace ) {
         flagsChanged = replaceFlags( pimItems, flags );
       } else if ( op == Add ) {
@@ -308,10 +309,13 @@ bool Store::parseStream()
     } else if ( command == AKONADI_CMD_COLLECTION ) {
       throw HandlerException( "Item moving via STORE is deprecated, update your Akonadi client" );
     } else { // parts/attributes
-     QByteArray partName, error;
+     QByteArray partName;
      qint64 partSize;
-     if ( !PartHelper::storeStreamedParts( command, m_streamParser, item, true, partName, partSize, error ) ) {
-       return failureResponse( error );
+     PartStreamer streamer( connection(), m_streamParser, item, this );
+     connect( &streamer, SIGNAL(responseAvailable(Akonadi::Server::Response)),
+              this, SIGNAL(responseAvailable(Akonadi::Server::Response)) );
+     if ( !streamer.stream( command, true, partName, partSize ) ) {
+       return failureResponse( streamer.error() );
      }
 
      changes << partName;
