@@ -38,8 +38,7 @@
 
 #include <QtCore/QTimer>
 
-namespace Akonadi
-{
+using namespace Akonadi::Server;
 
 PreprocessorInstance::PreprocessorInstance( const QString &id )
   : QObject()
@@ -61,10 +60,9 @@ bool PreprocessorInstance::init()
 
   mInterface = new OrgFreedesktopAkonadiPreprocessorInterface(
       AkDBus::agentServiceName( mId, AkDBus::Preprocessor ),
-      QLatin1String( "/" ),
+      QLatin1String( "/Preprocessor" ),
       QDBusConnection::sessionBus(),
-      this
-    );
+      this );
 
   if ( !mInterface || !mInterface->isValid() ) {
     Tracer::self()->warning(
@@ -248,5 +246,3 @@ void PreprocessorInstance::itemProcessed( qlonglong id )
   // Stay busy and process next item in the queue
   processHeadItem();
 }
-
-} // namespace Akonadi
