@@ -23,9 +23,13 @@
 #include <QObject>
 
 class QDBusAbstractInterface;
-class ItemRetrievalRequest;
 class QDBusError;
 
+namespace Akonadi {
+namespace Server {
+
+class ItemRetrievalRequest;
+
 /// Async D-Bus retrieval, no modification of the request (thus no need for locking)
 class ItemRetrievalJob : public QObject
 {
@@ -58,4 +62,7 @@ class ItemRetrievalJob : public QObject
     bool m_oldMethodCalled;
 };
 
+} // namespace Server
+} // namespace Akonadi
+
 #endif
