@@ -22,7 +22,7 @@
 
 #include "entities.h"
 
-#include "../../libs/notificationmessagev2_p.h"
+#include "../../libs/notificationmessagev3_p.h"
 
 #include <QtCore/QByteArray>
 #include <QtCore/QList>
@@ -30,6 +30,7 @@
 #include <QtCore/QString>
 
 namespace Akonadi {
+namespace Server {
 
 class DataStore;
 
@@ -94,6 +95,15 @@ class NotificationCollector : public QObject
                             const Collection &collection = Collection(),
                             const QByteArray &resource = QByteArray() );
 
+    /**
+     Notify about changed items tags
+    **/
+    void itemsTagsChanged( const PimItem::List &items,
+                           const QSet<qint64> &addedTags,
+                           const QSet<qint64> &removedTags,
+                           const Collection &collection = Collection(),
+                           const QByteArray &resource = QByteArray() );
+
     /**
       Notify about moved items
       Provide as many parameters as you have at hand currently, everything
@@ -167,13 +177,28 @@ class NotificationCollector : public QObject
     void collectionUnsubscribed( const Collection &collection,
                             const QByteArray &resource = QByteArray() );
 
+    /**
+      Notify about an added tag.
+     */
+    void tagAdded( const Tag &tag );
+
+    /**
+     Notify about a changed tag.
+     */
+    void tagChanged( const Tag &tag );
+
+    /**
+      Notify about a removed tag.
+     */
+    void tagRemoved( const Tag &tag );
+
     /**
       Trigger sending of collected notifications.
     */
     void dispatchNotifications();
 
   Q_SIGNALS:
-    void notify( const Akonadi::NotificationMessageV2::List &msgs );
+    void notify( const Akonadi::NotificationMessageV3::List &msgs );
 
   private:
     void itemNotification( NotificationMessageV2::Operation op, const PimItem::List &items,
@@ -182,7 +207,9 @@ class NotificationCollector : public QObject
                            const QByteArray &resource,
                            const QSet<QByteArray> &parts = QSet<QByteArray>(),
                            const QSet<QByteArray> &addedFlags = QSet<QByteArray>(),
-                           const QSet<QByteArray> &removedFlags = QSet<QByteArray>() );
+                           const QSet<QByteArray> &removedFlags = QSet<QByteArray>(),
+                           const QSet<qint64> &addedTags = QSet<qint64>(),
+                           const QSet<qint64> &removedTags = QSet<qint64>() );
     void itemNotification( NotificationMessageV2::Operation op, const PimItem &item,
                            const Collection &collection,
                            const Collection &collectionDest,
@@ -194,7 +221,9 @@ class NotificationCollector : public QObject
                                  const QByteArray &resource,
                                  const QSet<QByteArray> &changes = QSet<QByteArray>(),
                                  const QByteArray &destResource = QByteArray() );
-    void dispatchNotification( const NotificationMessageV2 &msg );
+    void tagNotification( NotificationMessageV2::Operation op,
+                          const Tag &tag );
+    void dispatchNotification( const NotificationMessageV3 &msg );
     void clear();
 
   private Q_SLOTS:
@@ -205,9 +234,10 @@ class NotificationCollector : public QObject
     DataStore *mDb;
     QByteArray mSessionId;
 
-    NotificationMessageV2::List mNotifications;
+    NotificationMessageV3::List mNotifications;
 };
 
-}
+} // namespace Server
+} // namespace Akonadi
 
 #endif
